---
categories:
- openSUSE
- Linux
- KDE
comments: true
date: '2022-10-07 23:10:14+02:00'
disable_share: true
draft: false
featured_image: /images/banner.jpg
omit_header_text: true
tags:
- opensuse
- linux
title: Translations available for KDE unstable packages
---

As many readers of this blog are aware, openSUSE has been [offering packages of git snapshots from KDE](https://en.opensuse.org/SDB:KDE_repositories#Unstable_Frameworks,_Plasma_and_Applications) since quite a while. They are quite useful for those wiling to test, report bugs, and / or hack on the code, but also for those who want to see what's brewing in KDE land ([without touching their existing systems](https://www.dennogumi.org/2016/02/where-are-my-noble-gases-i-need-more-noble-gases/)). However, a major drawback for non English speakers was the lack of translations.

## What's the problem with translations?

KDE translations are not hosted on the community's git repositories, but are instead stored in KDE's SVN server. The main reason they were not moved to git was to preserve the existing workflows of the translation teams (who might not be as technical as the actual hackers). Translations are then placed in tarballs at the times of betas / RCs / releases.

This unfortunately means that having a git checkout, like what the OBS does when building the unstable packages, will not carry any translations whatsoever. Worse, existing `-lang` packages for stable versions will raise dependency problems if present (because they require the exact same version of their corresponding binary paclage).

Also, since the KDE team tries to keep the same set of package defintions (spec files) between the stable and unstable OBS projects, this meant some extra complexity to take into account the fact that translations might or might not be there.

As far as I remember, since some time there was some tooling in KDE infrastructure to download translations at build time, but it was a big no-no for the OBS, as there is no network access during building for security reasons.

## Two sides of a solution

This proved to be a problem also for KDE's own release management. On September 2nd, KDE hacker Albert Astals Cid [outlined a proposal](https://mail.kde.org/pipermail/release-team/2022-September/012770.html) to have an automated way to copy translations from SVN into their corresponding repository, with a series of scripts that would do so periodically.

After some discussion and once at Akademy, the switch was turned on October 2nd. This means that our git checkouts were getting translations!

Of course, some adjustments were needed: spec files in the KDE Unstable projects were not taking the presence of translations into account, and thus quite a number of builds were failing. krop, KDE team member extraordinaire, stepped in and fixed all the spec files. This in turn made him realize that some upstream KDE projects were not actually handling translations correctly in their CMake code, so he fixed them too.

Within a couple days, all KDE Unstable repositories (Frameworks, Applications and Extra) had translations enabled, where applicable. After many years, it became possible to test the latest KDE software **and** have it in your own language.

## Do I need to do anything?

If you don't have the language packages installed and you have installation of recommended packages enabled (the default), they should be installed automatically. If you have, like myself, forcibly installed the language packages from the stable repositories, you can force install the new ones (for example with `zypper install -f <packagename>`), or if you're on Tumbleweed, accept to swap them when prompted (this occurs when a new stable version of KDE software is published in a snapshot). Or you can install them manually should you prefer to do so.

Should any issues with the packaging arise (e.g., missing dependencies, conflicts), please file a ticket on [bugzilla.opensuse.org](https://bugzilla.opensuse.org).

And as always, have a lot of fun!
